Index: fact/tools/pyscripts/pyfact/pyfact.py
===================================================================
--- fact/tools/pyscripts/pyfact/pyfact.py	(revision 13511)
+++ fact/tools/pyscripts/pyfact/pyfact.py	(revision 13512)
@@ -11,8 +11,8 @@
 # get the ROOT stuff + my shared libs
 from ROOT import gSystem
 # pyfits_h.so is made from pyfits.h and is used to access the data
 # make sure the location of pyfits_h.so is in LD_LIBRARY_PATH.
 # having it in PYTHONPATH is *not* sufficient
-gSystem.Load('pyfits_h.so')
+gSystem.Load('factfits_h.so')
 from ROOT import *
 
@@ -127,5 +127,5 @@
         # access data file
         try:
-            data_file = fits(self.data_file_name)
+            data_file = FactFits(self.data_file_name)
         except IOError:
             print 'problem accessing data file: ', data_file_name
@@ -161,5 +161,5 @@
         # open the calibration file
         try:
-            calib_file = fits(self.calib_file_name)
+            calib_file = FactFits(self.calib_file_name)
         except IOError:
             print 'problem accessing calibration file: ', calib_file_name
@@ -382,6 +382,6 @@
 # -----------------------------------------------------------------------------
 
-class SlowData( fits ):
-    """ -Fact Fits File-
+class SlowData( FactFits ):
+    """ -Fact SlowData File-
         A Python wrapper for the fits-class implemented in pyfits.h
         provides easy access to the fits file meta data.
@@ -395,5 +395,5 @@
         self.path = path
         try:
-            fits.__init__(self,path)
+            FactFits.__init__(self,path)
         except IOError:
             print 'problem accessing data file: ', data_file_name
@@ -11,8 +11,8 @@
 # get the ROOT stuff + my shared libs
 from ROOT import gSystem
-# pyfits_h.so is made from pyfits.h and is used to access the data
-# make sure the location of pyfits_h.so is in LD_LIBRARY_PATH.
+# factfits_h.so is made from factfits.h and is used to access the data
+# make sure the location of factfits_h.so is in LD_LIBRARY_PATH.
 # having it in PYTHONPATH is *not* sufficient
